@@ -23,11 +23,28 @@
 
 const int contents_pos = 0;
 
-HostBox::HostBox(Host* host, double row_height, double column_width)
-  :FrameBox(new Gtk::HBox(), Gdk::Color("blue"), row_height, column_width)
+HostBox::HostBox(Host* host, bool show_name, bool show_numeric_id, double row_height, double column_width, Pango::AttrList attrs)
+  :FrameBox(new Gtk::HBox(), Gdk::Color("black"), row_height, column_width),
+    text_attributes(attrs)
 {
   Gtk::HBox *contents = get_contents();
-  Gtk::HBox *box_contents = Box::ucompose("%1", host->get_name());
+  Gtk::HBox *box_contents;
+  int numeric_id = host->get_numeric_identifier();
+  std::string name = host->get_name();
+  if (host->get_friendly_name() != "")
+    name = host->get_friendly_name();
+  if (show_name && !show_numeric_id)
+    box_contents = Box::ucompose(text_attributes, "%1", name);
+  else if (!show_name && show_numeric_id && numeric_id >= 0)
+    box_contents = Box::ucompose(text_attributes, "%1", numeric_id);
+  else if (show_name && show_numeric_id && numeric_id >= 0)
+    box_contents = Box::ucompose(text_attributes, "%1 - %2", numeric_id, 
+                                 name);
+  else if (!show_name && show_numeric_id && numeric_id < 0)
+    box_contents = Box::ucompose(text_attributes, "%1", " ");
+  else
+    box_contents = Box::ucompose(text_attributes, "%1", name);
+
   contents->pack_start(*manage(box_contents), true, true, 0);
   set_host(host);
 }
@@ -40,9 +57,8 @@ void HostBox::set_host(Host *host)
 {
   if (is_realized())
     {
-      Gtk::HBox *box_contents = Box::ucompose("%1", host->get_name());
+      Gtk::HBox *box_contents = Box::ucompose(text_attributes, "%1", host->get_name());
       set_box_contents(box_contents);
     }
-  set_background_colour(Gdk::Color("light blue"));
+  set_background_colour(Gdk::Color("black"));
 }
-
