@@ -18,8 +18,8 @@
 #include "host-list-loader.h"
 
 
-HostListLoader::HostListLoader(HostList &hosts, std::string file, EventDate starting_time)
-  :hostlist(hosts), filename(file), starting_at(starting_time)
+HostListLoader::HostListLoader(HostList &hosts, std::string file, EventDate starting_time, ListerolaOptions::Source src_kind, bool &broken)
+  :hostlist(hosts), filename(file), starting_at(starting_time), kind(src_kind)
 {
 }
 
@@ -28,11 +28,13 @@ HostListLoader::~HostListLoader()
 }
 
 
-void HostListLoader::reload()
+bool HostListLoader::reload()
 {
+  return true;
 }
 
-Gdk::Color HostListLoader::genre_to_colour(std::string genre)
+void HostListLoader::set_listing_file(std::string file)
 {
-  return Gdk::Color("black");
+  filename = file;
+  reload();
 }
