@@ -22,18 +22,22 @@
 #include "event-date-region.h"
 #include "host-list.h"
 #include "host-list-loader.h"
+#include "listerola-options.h"
+#include <sigc++/connection.h>
+#include "sigc++/signal.h"
+#include <sigc++/trackable.h>
 class HostedEventList;
 
 class Host;
 class Event;
 class HostList;
 
-class Listerola
+class Listerola: public sigc::trackable
 {
     public:
 
 	//! Default constructor.
-	Listerola(std::string listings_file, double column_hours, double hour_interval);
+	Listerola(ListerolaOptions &opts);
 
 	//! Destructor.
         ~Listerola();
@@ -43,35 +47,57 @@ class Listerola
 
         HostedEventList get_events(Host *host = NULL);
 
-        double overlap_end(Event *event);
-        double overlap_start(Event *event);
+        double get_duration() {return opts.get_duration();};
 
-        double get_duration() {return get_current_date().get_duration();};
+        double get_num_rows() {return opts.get_num_rows();};
 
-        double get_interval() {return hour_interval;};
-
-        void next();
-    
-        void random_fill(int num_channels);
-        void load_xmltv();
+        std::string get_listing_file() const {return opts.get_listing_file();};
+        void set_listing_file(std::string f, ListerolaOptions::Source kind);
+        void reload_listing_file();
+        double get_interval() const {return opts.get_interval();};
+        double get_flipahead_interval() {return opts.get_flipahead_interval();};
+        EventDate get_last_refresh_date() const {return refresh_date;};
 
         HostList& get_host_list() {return channels;};
 
-        Gdk::Color genre_to_colour(std::string genre);
+        void next();
+        double overlap_end(Event *event);
+        double overlap_start(Event *event);
 
+        bool flip_ahead_to_next_interval();
+
+        std::list<std::string> get_genres();
+        int get_host_number(std::string n) {return opts.get_host_number(n);};
+        std::list<std::string> get_host_names();
+
+        sigc::signal<void> options_changed;
+        sigc::signal<void> listing_file_changed;
+        sigc::signal<void> bad_listing_file;
     private:
         HostList channels;
 
         HostListLoader *host_list_loader;
 
-        //! The data file that holds the channel listings.
-        std::string listings_file;
+        ListerolaOptions &opts;
 
         //! The window of time that we're interested in.
         EventDateRegion current_event_time;
 
-        //! The length of each slice of our window in time.
-        double hour_interval;
+        //! When the listing file was last read.
+        EventDate refresh_date;
+
+        //! helper functions
+        void update_host_list_loader();
+        void sort_host_list();
+        static bool sort_by_numeric_id(const Host *lhs, const Host *rhs);
+
+        //! Callbacks
+        void on_duration_changed();
+        void on_listing_file_changed();
+        void on_host_numbers_changed();
+        void on_host_names_changed();
+
+        void on_bad_file_format(); //remove me
 };
 
 #endif //LISTEROLA_H
